@@ -59,31 +59,33 @@ class Options(argparse.ArgumentParser):
         pipeline_group.add_argument("--write-fastq-reverse-complement",
             dest="write_fastq_reverse_complement", action="store_true", default=True)
 
+    def parse_args(self, *args):
+        args_list = list(*args)
+        if "--from-project" in args_list:
+            if len(args_list)>2:
+                msg = "WARNING [sequana]: With --from-project option, " + \
+                        "pipeline and data-related options will be ignored."
+                print(col.error(msg))
+            for action in self._actions:
+                if action.required is True:
+                    action.required = False
+        options = super(Options, self).parse_args(*args)
+        return options
 
 def main(args=None):
 
     if args is None:
         args = sys.argv
 
-    #if "--version" in sys.argv:
-    #    from sequana_pipetools.misc import print_version
-    #    print_version(NAME)
-    #    sys.exit(0)
-
     # whatever needs to be called by all pipeline before the options parsing
-    from sequana_pipetools.options import init_pipeline
-    init_pipeline(NAME)
+    from sequana_pipetools.options import before_pipeline
+    before_pipeline(NAME)
 
     # option parsing including common epilog
     options = Options(NAME, epilog=sequana_epilog).parse_args(args[1:])
 
-    from sequana.snaketools import Module
-    m = Module(NAME)
-    m.is_executable()
-
-    from sequana import logger
     from sequana.pipelines_common import SequanaManager
-    logger.level = "INFO"
+
     # the real stuff is here
     manager = SequanaManager(options, NAME)
 
@@ -125,23 +127,23 @@ def main(args=None):
                     logger.warning(msg)
                     sys.exit(1)
 
+    if options.from_project is None:
+        cfg = manager.config.config
+        cfg.input_directory = os.path.abspath(options.bcl_directory)
+        cfg.bcl2fastq.threads = options.threads
+        cfg.bcl2fastq.barcode_mismatch = options.mismatch
+        cfg .bcl2fastq.sample_sheet_file = os.path.abspath(options.samplesheet)
 
-    cfg = manager.config.config
-    cfg.input_directory = os.path.abspath(options.bcl_directory)
-    cfg.bcl2fastq.threads = options.threads
-    cfg.bcl2fastq.barcode_mismatch = options.mismatch
-    cfg.bcl2fastq.sample_sheet_file = os.path.abspath(options.samplesheet)
-
-    # this is defined by the working_directory
-    cfg.bcl2fastq.output_directory = "."
-    cfg.bcl2fastq.ignore_missing_controls= options.ignore_missing_controls
-    cfg.bcl2fastq.ignore_missing_bcls = options.ignore_missing_bcls
-    cfg.bcl2fastq.no_bgzf_compression = options.no_bgzf_compression
-    if options.merging_strategy == "merge":
-        cfg.bcl2fastq.merge_all_lanes = True
-    elif options.merging_strategy in  ["none", "none_and_force"]:
-        cfg.bcl2fastq.merge_all_lanes = False
-    cfg.bcl2fastq.write_fastq_reverse_complement = options.write_fastq_reverse_complement
+        # this is defined by the working_directory
+        cfg.bcl2fastq.output_directory = "."
+        cfg.bcl2fastq.ignore_missing_controls= options.ignore_missing_controls
+        cfg.bcl2fastq.ignore_missing_bcls = options.ignore_missing_bcls
+        cfg.bcl2fastq.no_bgzf_compression = options.no_bgzf_compression
+        if options.merging_strategy == "merge":
+            cfg.bcl2fastq.merge_all_lanes = True
+        elif options.merging_strategy in  ["none", "none_and_force"]:
+            cfg.bcl2fastq.merge_all_lanes = False
+        cfg.bcl2fastq.write_fastq_reverse_complement = options.write_fastq_reverse_complement
 
     # finalise the command and save it; copy the snakemake. update the config
     # file and save it.
